.. _install:

Install and configure
~~~~~~~~~~~~~~~~~~~~~

This section describes how to install and configure the
Orchestration service, code-named heat, on the controller node.

This section assumes that you already have a working OpenStack
environment with at least the following components installed:
Compute, Image Service, Identity.

Note that installation and configuration vary by distribution.

.. toctree::
   :maxdepth: 1

   install-obs.rst
   install-rdo.rst
   install-ubuntu.rst
   install-debian.rst
